@@ -2,8 +2,10 @@ import datetime
 import logging
 import re
 from enum import Enum
+
+from db_hammer.entity_util import update_sql, insert_sql, delete_sql
+
 from db_hammer.csv import start as csv_start
-from db_hammer.entity_util import get_insert_sql, get_update_sql
 from db_hammer.sql_exception import SqlException
 from db_hammer.util.date import date_to_str
 
@@ -40,11 +42,11 @@ class BaseConnection(object):
         """
 
         count_sql = "select COUNT(0) from ( %s ) temp_count" % sql
-        count_sql, p_list = self.sql_params(count_sql, params)
-        self.log.debug("execute sql ==>:" + count_sql.replace("\n", " "))
-        self.cursor.execute(count_sql, p_list)
+        count_sql = self.sql_params(count_sql, params)
+        self.log.debug("execute sql :" + count_sql.replace("\n", " "))
+        self.cursor.execute(count_sql, params)
         data = self.cursor.fetchone()
-        self.log.debug("fetch rows  <==:" + str(len(data)))
+        self.log.debug("fetch rows:" + str(len(data)))
         num = data[0] // page_size
         if data[0] > page_size * num:
             num = num + 1
@@ -53,31 +55,16 @@ class BaseConnection(object):
     def sql_params(self, sql: str, params: dict):
         if params is None:
             return sql
-        p_list = []
         ps = re.findall('(?<!\w):\w+', sql)
         start = 0
         for p in ps:
             if p[1:] not in params or len(p) == 1:
                 raise SqlException(f"SQL语句中参数[{p}]没有传值")
-            value = params.get(p[1:])
-            if isinstance(value, (str, datetime.date, datetime.datetime)):
-                start = sql.find(p, start)
-                sql = sql[:start] + "%s" + sql[start + len(p):]
-                start += 2
-                p_list.append(value)
-            elif isinstance(value, int):
-                start = sql.find(p, start)
-                sql = sql[:start] + "%d" + sql[start + len(p):]
-                start += 2
-                p_list.append(value)
-            elif isinstance(value, float):
-                start = sql.find(p, start)
-                sql = sql[:start] + "%f" + sql[start + len(p):]
-                start += 2
-                p_list.append(value)
-            else:
-                raise SqlException(f"传值不支持类型：" + str(type(value)))
-        return sql, p_list
+            start = sql.find(p, start)
+            param = "%(" + p[1:] + ")s"
+            sql = sql[:start] + param + sql[start + len(p):]
+            start += len(param)
+        return sql
 
     def select_page_list(self, sql: str, page_size=50, page_start=1, **kwargs) -> list:
         """
@@ -105,11 +92,11 @@ class BaseConnection(object):
                          ( %s ) temp_page 
                        where limit %d,%d
                        """ % (sql, end, start)
-        page_sql, p_list = self.sql_params(page_sql, params)
-        self.log.debug("execute sql ==>:" + page_sql.replace("\n", " "))
-        self.cursor.execute(page_sql, p_list)
+        page_sql = self.sql_params(page_sql, params)
+        self.log.debug("execute sql :" + page_sql.replace("\n", " "))
+        self.cursor.execute(page_sql, params)
         data = self.cursor.fetchall()
-        self.log.debug("fetch rows  <==:" + str(len(data)))
+        self.log.debug("fetch rows:" + str(len(data)))
         if add_headers:
             col_names = self.cursor.description
             list(data).insert(col_names, 0)
@@ -140,9 +127,9 @@ class BaseConnection(object):
         :param sql:
         :return:
         """
-        self.log.debug("execute sql ==>:" + sql.replace("\n", " "))
-        _sql, p_list = self.sql_params(sql, params)
-        self.cursor.execute(_sql, p_list)
+        self.log.debug("execute sql :" + sql.replace("\n", " "))
+        _sql = self.sql_params(sql, params)
+        self.cursor.execute(_sql, params)
         data = self.cursor.fetchone()
         if data is None:
             return None
@@ -154,11 +141,11 @@ class BaseConnection(object):
         :param sql:
         :return:
         """
-        self.log.debug("execute sql ==>:" + sql.replace("\n", " "))
-        _sql, p_list = self.sql_params(sql, params)
-        self.cursor.execute(_sql, p_list)
+        self.log.debug("execute sql :" + sql.replace("\n", " "))
+        _sql = self.sql_params(sql, params)
+        self.cursor.execute(_sql, params)
         data = self.cursor.fetchall()
-        self.log.debug("fetch rows  <==:" + str(len(data)))
+        self.log.debug("fetch rows:" + str(len(data)))
         return data
 
     def select_dict_list(self, sql: str, params=None) -> list:
@@ -168,11 +155,11 @@ class BaseConnection(object):
         :param sql:
         :return:
         """
-        self.log.debug("execute sql ==>:" + sql.replace("\n", " "))
-        _sql, p_list = self.sql_params(sql, params)
-        self.cursor.execute(_sql, p_list)
+        self.log.debug("execute sql :" + sql.replace("\n", " "))
+        _sql = self.sql_params(sql, params)
+        self.cursor.execute(_sql, params)
         data = self.cursor.fetchall()
-        self.log.debug("fetch rows  <==:" + str(len(data)))
+        self.log.debug("fetch rows:" + str(len(data)))
         col_names = self.cursor.description
         return self._data_to_map(col_names, data)
 
@@ -205,10 +192,10 @@ class BaseConnection(object):
         :param sql:
         :return:
         """
-        self.log.debug("execute sql ==>:" + sql.replace("\n", " "))
+        # self.log.debug("execute sql :" + sql.replace("\n", " "))
         self.cursor.execute(sql, params)
         i = self.cursor.rowcount
-        self.log.debug("fetch rows  <==:" + str(i))
+        self.log.debug("fetch rows:" + str(i))
         return i
 
     def close(self):
@@ -339,6 +326,7 @@ class BaseConnection(object):
         return update_sql
 
     def __get_column_value(self, data_type, value):
+        """获取列的值"""
         if data_type is None:
             return f"'{self.convert_str(value)}'"
         t = self.__get_py_type(db_type=data_type)
@@ -396,27 +384,34 @@ class BaseConnection(object):
 
     def insert_entity(self, entity):
         """传入实体保存到数据库"""
-        sql = get_insert_sql(entity=entity, fn_db_value=self.__get_column_value)
+        sql, values = insert_sql(entity=entity)
         self.log.debug(sql)
-        return self.execute(sql)
+        self.log.debug(f"params:{values}")
+        sql = self.sql_params(sql, values)
+        i = self.execute(sql, values)
+        self.commit()
+        return i
 
-    def update_entity(self, entity):
-        sql = get_update_sql(entity=entity, fn_db_value=self.__get_column_value)
+    def update_entity(self, entity, pass_null=False):
+        sql, values = update_sql(entity=entity, pass_null=pass_null)
+        self.log.debug(f"SQL:{sql}")
+        self.log.debug(f"params:{values}")
+        sql = self.sql_params(sql, values)
+        i = self.execute(sql, values)
+        self.commit()
+        return i
+
+    def delete_entity(self, entity):
+        sql, values = delete_sql(entity=entity)
         self.log.debug(sql)
-        # return self.execute(sql)
+        self.log.debug(f"params:{values}")
+        sql = self.sql_params(sql, values)
+        i = self.execute(sql, values)
+        self.commit()
+        return i
 
-    def update_entity_select(self, entity):
-        sql = get_update_sql(entity=entity, fn_db_value=self.__get_column_value)
-        self.log.debug(sql)
-
-    def delete_entity_by_primary_key(self):
-        print("delete_by_primary_key")
-
-    def delete_entity_by_columns(self):
-        print("delete_by_columns")
-
-    def select_entity_list_by_columns(self):
+    def select_entity_list(self):
         print("select_list_by_columns")
 
-    def select_entity_one_by_columns(self):
+    def select_entity_one(self):
         print("select_one_by_columns")
